@@ -12,10 +12,11 @@ def get_resp(response=None):
 def try_solcatcher_io(method = None):
   method = get_method(method=method)
   try:
-    response = postFlaskRequest(url=getSolcatcherFlaskUrl(),endpoint='rate_limit',data=json.dumps({"method":method}),status_code=True)
-    return response 
+    url,status_code = postFlaskRequest(url=getSolcatcherFlaskUrl(),endpoint='get_rate_limit',data=json.dumps({"method":method}),status_code=True)
+    return url,status_code 
   except:
     pass
+  return None,500
 def try_log_response(method = None,response=None):
   method = get_method(method=method)
   response = get_resp(response=response)
@@ -48,13 +49,13 @@ class CheckSolcatcher(metaclass=SingletonMeta):
        url = self.rateLimiter.get_url(method=method)
     return get_url(url=url)
   
-  def log_response(method=None,response=None):
+  def log_response(self,method=None,response=None):
     if self.solcatcher_on:
        try_log_response(method = method,response=response)
     if self.solcatcher_on == False:
       method = get_method(method=method)
       response = get_resp(response=response)
-      self.rateLimiter.log_response(method=method)  
+      self.rateLimiter.log_response(method=method,response=response)  
 def getSolcatcherUrl(callType=None):
   if callType == 'flask':
     return getSolcatcherFlaskUrl()
